@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::PERLANCAR::AddDeps;
 
 our $DATE = '2015-05-15'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,7 +33,7 @@ sub gather_files {
 
     my $res = call_lcpan_script(argv => ['deps', '-R', @$modules]);
 
-    my %add_mods; # to be added in our dist
+    my %add_mods = (map {$_=>0} @$modules); # to be added in our dist
     my %dep_mods; # to stay as deps
     for my $rec (@$res) {
         my $add = 0;
@@ -118,7 +118,7 @@ Dist::Zilla::Plugin::PERLANCAR::AddDeps - Include dependencies into dist
 
 =head1 VERSION
 
-This document describes version 0.05 of Dist::Zilla::Plugin::PERLANCAR::AddDeps (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-AddDeps), released on 2015-05-15.
+This document describes version 0.06 of Dist::Zilla::Plugin::PERLANCAR::AddDeps (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-AddDeps), released on 2015-05-15.
 
 =head1 SYNOPSIS
 
